# server

HTTP server.

## Features

- Low latency
- Radix tree routing

## Installation

```shell
go get git.akyoto.dev/go/server
```

## Usage

```go
s := server.New()

// Static route
s.Get("/", func(ctx server.Context) error {
	return ctx.String("Hello")
})

// Parameter route
s.Get("/blog/:post", func(ctx server.Context) error {
	return ctx.String(ctx.Get("post"))
})

// Wildcard route
s.Get("/images/*file", func(ctx server.Context) error {
	return ctx.String(ctx.Get("file"))
})

s.Run(":8080")
```

## Tests

```
PASS: TestRouter
PASS: TestMiddleware
PASS: TestPanic
PASS: TestRun
PASS: TestUnavailablePort
coverage: 100.0% of statements
```

## Benchmarks

```
BenchmarkHello-12       31128832                38.41 ns/op            0 B/op          0 allocs/op
BenchmarkGitHub-12      17406580                68.56 ns/op            0 B/op          0 allocs/op
```

## License

Please see the [license documentation](https://akyoto.dev/license).

## Copyright

© 2023 Eduard Urbach
